@@ -74,7 +74,7 @@ _LFoutput_fmt = [
     {'file': 'MaxHeights.txt', 'column': 6, 'short_name': 'time_of_maximum', 'long_name': 'Time of the maximum depth', 'symbol': 't_maxh', 'units': 's', 'dtype': 'real', 'infile': True, },
     {'file': 'MaxSpeeds.txt', 'column': 5, 'short_name': 'maximum_speed', 'long_name': 'Maximum speed of lahar', 'symbol': 'maxspd', 'units': 'm/s', 'dtype': 'real', 'infile': True, },
     {'file': 'MaxSpeeds.txt', 'column': 6, 'short_name': 'time_of_maximum', 'long_name': 'Time of the maximum speed', 'symbol': 't_maxspd', 'units': 's', 'dtype': 'real', 'infile': True, },
-    {'file': 'InundationTime.txt', 'column': 5, 'short_name': 'inundation_time', 'long time': 'Time of first inundation', 'symbol': 't_inun', 'units': 's', 'dtype': 'real', 'infile': True, },
+    {'file': 'InundationTime.txt', 'column': 5, 'short_name': 'inundation_time', 'long_name': 'Time of first inundation', 'symbol': 't_inun', 'units': 's', 'dtype': 'real', 'infile': True, },
 ]
 _LFoutput_shortnames = [d['short_name'] for d in _LFoutput_fmt]
 def _get_LF_output_fmt(short_name, filetype='snapshot'):
@@ -82,7 +82,7 @@ def _get_LF_output_fmt(short_name, filetype='snapshot'):
         ret = next(item for item in _LFoutput_fmt if item['short_name'] == short_name and item['file'] in [filetype, 'all'])
     except:
         warnings.warn('Item {} not in known output formats for filetype {}'.format(short_name, filetype))
-        ret = {'file': 'unknown', 'short_name': short_name, 'long time': short_name.replace('_', ' '), 'symbol': '', 'units': '', 'dtype': '', 'infile': True, }
+        ret = {'file': 'unknown', 'short_name': short_name, 'long_name': short_name.replace('_', ' '), 'symbol': '', 'units': '', 'dtype': '', 'infile': True, }
     return ret
 
 class LaharFlowData(object):
